@@ -10,7 +10,7 @@ from .utils import FileInfoProvider
 
 
 class FfmpegProcess:
-    def __init__(self, command, ffmpeg_loglevel="panic"):
+    def __init__(self, command, ffmpeg_loglevel="verbose"):
         """
         Creates the list of FFmpeg arguments.
         Accepts an optional ffmpeg_loglevel parameter to set the value of FFmpeg's -loglevel argument.
@@ -51,7 +51,7 @@ class FfmpegProcess:
         eta_string = "unknown"
         ffmpeg_stderr = ""
 
-        #print("Running FFmpeg...")
+        print("Running FFmpeg...")
 
         with open(ffmpeg_output_file, "a") as f:
             self._process = subprocess.Popen(
@@ -61,29 +61,25 @@ class FfmpegProcess:
             )
 
         input_file_info = FileInfoProvider(filepath)
-        duration_secs = int(input_file_info.get_duration())
-        print(f"DURATION: {duration_secs}")
+        duration_microseconds = input_file_info.get_duration() * 1_000_000
 
         progress_bar = tqdm(
-            total=duration_secs,
+            total=duration_microseconds,
             dynamic_ncols=True
         )
 
         progress_bar.clear()
-        previous_seconds_processed = 0
+        previous_microseconds_processed = 0
 
         try:
             while self._process.poll() is None:
                 line = self._process.stdout.readline().decode("utf-8")
                 # out_time_ms=3505000
                 if "out_time_ms" in line:
-                    print(f"Line: {line}")
-                    seconds_processed = int(line.strip()[12:]) / 1000
-                    print(f"Processed: {seconds_processed}")
-                    seconds_increase = seconds_processed - previous_seconds_processed
-                    print(f"INCREASE: {seconds_increase}")
-                    progress_bar.update(seconds_increase)
-                    previous_seconds_processed = seconds_processed
+                    microseconds_processed = int(line.strip()[12:])
+                    microseconds_increase = microseconds_processed - previous_microseconds_processed
+                    progress_bar.update(microseconds_increase)
+                    previous_microseconds_processed = microseconds_processed
         except KeyboardInterrupt:
             progress_bar.close()
             self._process.kill()
